@@ -336,6 +336,11 @@ class Export
     {
         $file_handle = null;
         $message = '';
+        $doNotSaveItOver = true;
+
+        if(isset($_POST['quick_export_onserver_overwrite'])) {
+            $doNotSaveItOver = $_POST['quick_export_onserver_overwrite'] != 'saveitover';
+        }
 
         $save_filename = Util::userDir($GLOBALS['cfg']['SaveDir'])
             . preg_replace('@[/\\\\]@', '_', $filename);
@@ -343,7 +348,7 @@ class Export
         if (@file_exists($save_filename)
             && ((! $quick_export && empty($_POST['onserver_overwrite']))
             || ($quick_export
-            && $_POST['quick_export_onserver_overwrite'] != 'saveitover'))
+            && $doNotSaveItOver))
         ) {
             $message = Message::error(
                 __(
@@ -486,24 +491,13 @@ class Export
         }
 
         // Convert the multiple select elements from an array to a string
-        if ($export_type == 'server' && isset($_POST['db_select'])) {
-            $_POST['db_select'] = implode(",", $_POST['db_select']);
-        } elseif ($export_type == 'database') {
-            if (isset($_POST['table_select'])) {
-                $_POST['table_select'] = implode(",", $_POST['table_select']);
+        if ($export_type == 'database') {
+            $structOrDataForced = empty($_POST['structure_or_data_forced']);
+            if ($structOrDataForced && ! isset($_POST['table_structure'])) {
+                $_POST['table_structure'] = [];
             }
-            if (isset($_POST['table_structure'])) {
-                $_POST['table_structure'] = implode(
-                    ",",
-                    $_POST['table_structure']
-                );
-            } elseif (empty($_POST['structure_or_data_forced'])) {
-                $_POST['table_structure'] = '';
-            }
-            if (isset($_POST['table_data'])) {
-                $_POST['table_data'] = implode(",", $_POST['table_data']);
-            } elseif (empty($_POST['structure_or_data_forced'])) {
-                $_POST['table_data'] = '';
+            if ($structOrDataForced && ! isset($_POST['table_data'])) {
+                $_POST['table_data'] = [];
             }
         }
 
@@ -520,11 +514,11 @@ class Export
         foreach($_POST as $name => $value) {
             if (is_array($value)) {
                 foreach($value as $val) {
-                    $refreshButton .= '<input type="hidden" name="' . urlencode((string) $name) . '[]" value="' . urlencode((string) $val) . '">';
+                    $refreshButton .= '<input type="hidden" name="' . htmlentities((string) $name) . '[]" value="' . htmlentities((string) $val) . '">';
                 }
             }
             else {
-                $refreshButton .= '<input type="hidden" name="' . urlencode((string) $name) . '" value="' . urlencode((string) $value) . '">';
+                $refreshButton .= '<input type="hidden" name="' . htmlentities((string) $name) . '" value="' . htmlentities((string) $value) . '">';
             }
         }
         $refreshButton .= '</form>';
