@@ -26,7 +26,7 @@ if (! $response->isAjax()) {
     exit;
 }
 
-if (isset($_REQUEST['getNaviSettings']) && $_REQUEST['getNaviSettings']) {
+if (isset($_POST['getNaviSettings']) && $_POST['getNaviSettings']) {
     $response->addJSON('message', PageSettings::getNaviSettings());
     exit();
 }
@@ -34,41 +34,41 @@ if (isset($_REQUEST['getNaviSettings']) && $_REQUEST['getNaviSettings']) {
 $relation = new Relation();
 $cfgRelation = $relation->getRelationsParam();
 if ($cfgRelation['navwork']) {
-    if (isset($_REQUEST['hideNavItem'])) {
-        if (! empty($_REQUEST['itemName'])
-            && ! empty($_REQUEST['itemType'])
-            && ! empty($_REQUEST['dbName'])
+    if (isset($_POST['hideNavItem'])) {
+        if (! empty($_POST['itemName'])
+            && ! empty($_POST['itemType'])
+            && ! empty($_POST['dbName'])
         ) {
             $navigation->hideNavigationItem(
-                $_REQUEST['itemName'],
-                $_REQUEST['itemType'],
-                $_REQUEST['dbName'],
-                (! empty($_REQUEST['tableName']) ? $_REQUEST['tableName'] : null)
+                $_POST['itemName'],
+                $_POST['itemType'],
+                $_POST['dbName'],
+                (! empty($_POST['tableName']) ? $_POST['tableName'] : null)
             );
         }
         exit;
     }
 
-    if (isset($_REQUEST['unhideNavItem'])) {
-        if (! empty($_REQUEST['itemName'])
-            && ! empty($_REQUEST['itemType'])
-            && ! empty($_REQUEST['dbName'])
+    if (isset($_POST['unhideNavItem'])) {
+        if (! empty($_POST['itemName'])
+            && ! empty($_POST['itemType'])
+            && ! empty($_POST['dbName'])
         ) {
             $navigation->unhideNavigationItem(
-                $_REQUEST['itemName'],
-                $_REQUEST['itemType'],
-                $_REQUEST['dbName'],
-                (! empty($_REQUEST['tableName']) ? $_REQUEST['tableName'] : null)
+                $_POST['itemName'],
+                $_POST['itemType'],
+                $_POST['dbName'],
+                (! empty($_POST['tableName']) ? $_POST['tableName'] : null)
             );
         }
         exit;
     }
 
-    if (isset($_REQUEST['showUnhideDialog'])) {
-        if (! empty($_REQUEST['dbName'])) {
+    if (isset($_POST['showUnhideDialog'])) {
+        if (! empty($_POST['dbName'])) {
             $response->addJSON(
                 'message',
-                $navigation->getItemUnhideDialog($_REQUEST['dbName'])
+                $navigation->getItemUnhideDialog($_POST['dbName'])
             );
         }
         exit;
