@@ -41,8 +41,8 @@ $back = 'tbl_sql.php';
 $response->addHTML(
     SqlQueryForm::getHtml(
         true, false,
-        isset($_REQUEST['delimiter'])
-        ? htmlspecialchars($_REQUEST['delimiter'])
+        isset($_POST['delimiter'])
+        ? htmlspecialchars($_POST['delimiter'])
         : ';'
     )
 );
